#include <pi-address.h>
#include "../jpilot_src/libplugin.h"
#include "pytype_basics.h"

extern PyObject* PyPiAddress_New();
extern PyObject* PyPiAddress_Wrap(struct Address*, PCRecType, unsigned int, unsigned char,
				 int, void*, PyObject *);

extern PyTypeObject AddressType;

#define PyPiAddress_Check(v)          PyObject_TypeCheck(v, &AddressType)
#define PyPiAddress_CheckExact(v)     ((v)->ob_type == &AddressType)

typedef struct {
  PyObject_HEAD
  PyObject_JPTYPE
  struct Address a;
} PyPiAddress;
